summaryrefslogtreecommitdiff
path: root/sc
diff options
context:
space:
mode:
authorNoel Grandin <noel@peralex.com>2013-09-17 12:49:11 +0200
committerNoel Grandin <noel@peralex.com>2013-09-19 10:14:14 +0200
commit3c38dd9bfec5752fa6486be355eca266db14bf66 (patch)
treeeaf1fcf7d0c7f14c51e6d250c07914eef17bbb9a /sc
parent4f684749432a9811e9d13d34a3f44143acb0f5b1 (diff)
convert sc/inc/externalrefmgr.hxx from String to OUString
Change-Id: I71c755f05eb47e26193ae87cb2f9cd618cfaf13d
Diffstat (limited to 'sc')
-rw-r--r--sc/inc/externalrefmgr.hxx11
-rw-r--r--sc/source/ui/docshell/externalrefmgr.cxx6
2 files changed, 8 insertions, 9 deletions
diff --git a/sc/source/ui/docshell/externalrefmgr.cxx b/sc/source/ui/docshell/externalrefmgr.cxx
index 40cbb2b652c3..6ee849eb03f9 100644
--- a/sc/source/ui/docshell/externalrefmgr.cxx
+++ b/sc/source/ui/docshell/externalrefmgr.cxx
@@ -866,7 +866,7 @@ void ScExternalRefCache::initializeDoc(sal_uInt16 nFileId, const vector<OUString
pDoc->mbInitFromSource = true;
}
-String ScExternalRefCache::getTableName(sal_uInt16 nFileId, size_t nCacheId) const
+OUString ScExternalRefCache::getTableName(sal_uInt16 nFileId, size_t nCacheId) const
{
if( DocItem* pDoc = getDocItem( nFileId ) )
if( nCacheId < pDoc->maTableNames.size() )
@@ -1201,7 +1201,7 @@ ScExternalRefCache::DocItem* ScExternalRefCache::getDocItem(sal_uInt16 nFileId)
// ============================================================================
-ScExternalRefLink::ScExternalRefLink(ScDocument* pDoc, sal_uInt16 nFileId, const String& rFilter) :
+ScExternalRefLink::ScExternalRefLink(ScDocument* pDoc, sal_uInt16 nFileId, const OUString& rFilter) :
::sfx2::SvBaseLink(::sfx2::LINKUPDATE_ONCALL, FORMAT_FILE),
mnFileId(nFileId),
maFilterName(rFilter),
@@ -2323,7 +2323,7 @@ void ScExternalRefManager::maybeLinkExternalFile(sal_uInt16 nFileId)
maLinkedDocs.insert(LinkedDocMap::value_type(nFileId, true));
}
-void ScExternalRefManager::SrcFileData::maybeCreateRealFileName(const String& rOwnDocName)
+void ScExternalRefManager::SrcFileData::maybeCreateRealFileName(const OUString& rOwnDocName)
{
if (maRelativeName.isEmpty())
// No relative path given. Nothing to do.
diff --git a/sc/inc/externalrefmgr.hxx b/sc/inc/externalrefmgr.hxx
index 20deaed7e074..9852b60c3507 100644
--- a/sc/inc/externalrefmgr.hxx
+++ b/sc/inc/externalrefmgr.hxx
@@ -43,7 +43,6 @@
class ScDocument;
class ScTokenArray;
-class String;
class SfxObjectShellRef;
class Window;
class ScFormulaCell;
@@ -53,7 +52,7 @@ class ScExternalRefCache;
class ScExternalRefLink : public ::sfx2::SvBaseLink
{
public:
- ScExternalRefLink(ScDocument* pDoc, sal_uInt16 nFileId, const String& rFilter);
+ ScExternalRefLink(ScDocument* pDoc, sal_uInt16 nFileId, const OUString& rFilter);
virtual ~ScExternalRefLink();
virtual void Closed();
@@ -70,7 +69,7 @@ private:
DECL_LINK( ExternalRefEndEditHdl, void* );
sal_uInt16 mnFileId;
- String maFilterName;
+ OUString maFilterName;
ScDocument* mpDoc;
bool mbDoRefresh;
};
@@ -242,7 +241,7 @@ public:
bool isDocInitialized(sal_uInt16 nFileId);
void initializeDoc(sal_uInt16 nFileId, const ::std::vector<OUString>& rTabNames);
- String getTableName(sal_uInt16 nFileId, size_t nCacheId) const;
+ OUString getTableName(sal_uInt16 nFileId, size_t nCacheId) const;
void getAllTableNames(sal_uInt16 nFileId, ::std::vector<OUString>& rTabNames) const;
SCsTAB getTabSpan( sal_uInt16 nFileId, const OUString& rStartTabName, const OUString& rEndTabName ) const;
void getAllNumberFormats(::std::vector<sal_uInt32>& rNumFmts) const;
@@ -413,7 +412,7 @@ public:
OUString maFilterOptions;
bool bUnsaved;
- void maybeCreateRealFileName(const String& rOwnDocName);
+ void maybeCreateRealFileName(const OUString& rOwnDocName);
};
public:
@@ -573,7 +572,7 @@ public:
* If false, it returns an URI adjusted for
* relocated document.
*
* @return const String* external document URI.
*/
const OUString* getExternalFileName(sal_uInt16 nFileId, bool bForceOriginal = false);
bool hasExternalFile(sal_uInt16 nFileId) const;
@@ -573,7 +572,7 @@ public:
* relocated document.
*
- * @return const String* external document URI.
+ * @return const OUString* external document URI.
*/
const OUString* getExternalFileName(sal_uInt16 nFileId, bool bForceOriginal = false);